from distutils.core import setup

setup(
    name = 'dbb_de_nester',
    version = '1.2.0',
    py_modules = ['nester'],
    author = 'dbb',
    author_email = '2923555602@qq.com',
    url = '',
    description = 'A simple printer of nested lists.'
)
